==> kbtv-1.1.1.tbz: kbtv-1.1.1/do_clean.py <==
import os, commands, buildprefs

os.chdir("bt848")
for item in os.listdir("."):
    if not item in ("bt848.h", "bt848.c", "btviewer.c"):
        os.remove(item)
if buildprefs.WITH_PWC:
    os.chdir("../pwc")
    for item in os.listdir("."):
        if  not item in ("pwc.h", "pwc.c", "patches"):
            if item == "pwcbsd":
                os.chdir("pwcbsd")
                res = commands.getoutput("make clean")
                os.chdir("..")
            else:
                os.remove(item)
if buildprefs.WITH_SAA:
    os.chdir("../saa")
    for item in os.listdir("."):
        if not item in ("saa.h", "saa.c", "saaviewer.c", "patches"):
            if item == "saa":
                os.chdir("saa")
                os.rename("Makefile.orig", "Makefile")
                os.rename("support/tuner_ctrl.h.orig", "support/tuner_ctrl.h")
                res = commands.getoutput("make clean")
                os.chdir("..")
            else:
                os.remove(item)
os.chdir("../ui")
for item in os.listdir("."):
    if not item.endswith(".ui"):
        os.remove(item)
os.chdir("../modules")
for item in os.listdir("."):
    if not item.endswith(".py"):
        os.remove(item)
os.chdir("../Kbtv")
for item in os.listdir("."):
    if not (item.endswith(".py") or item.endswith(".rc")):
        os.remove(item)
os.chdir("../doc")
for item in os.listdir("."):
    for doc in os.listdir(item):
        if doc.endswith(".html") or doc.endswith(".bz2") or doc.endswith("~"):
            os.remove(os.path.join(item, doc))
os.chdir("..")
for item in os.listdir("."):
    if ((item.endswith(".pyc") or item in ("kbtv", "btsetup", "kbtv.desktop")) 
        and not os.path.isdir(item)):
        os.remove(item)

==> kbtv-1.1.3.tbz: kbtv-1.1.3/do_clean.py <==
import os, commands, buildprefs

os.chdir("bt848")
for item in os.listdir("."):
    if not item in ("bt848.h", "bt848.c", "btviewer.c"):
        os.remove(item)
if buildprefs.WITH_PWC:
    os.chdir("../pwc")
    for item in os.listdir("."):
        if  not item in ("pwc.h", "pwc.c", "patches"):
            if item == "pwcbsd":
                os.chdir("pwcbsd")
                res = commands.getoutput("make clean")
                os.chdir("..")
            else:
                os.remove(item)
if buildprefs.WITH_SAA:
    os.chdir("../saa")
    for item in os.listdir("."):
        if not item in ("saa.h", "saa_reg.h", "saa_var.h", "saa.c", 
                        "saaviewer.c", "patches"):
            if item == "saa":
                os.chdir("saa")
                # Put back old Makefiles, because do_build uses patch
                os.rename("kmod/Makefile.orig", "kmod/Makefile")
                os.rename("Makefile.orig", "Makefile")
                res = commands.getoutput("make clean")
                os.chdir("..")
            else:
                os.remove(item)
os.chdir("../ui")
for item in os.listdir("."):
    if not item.endswith(".ui"):
        os.remove(item)
os.chdir("../modules")
for item in os.listdir("."):
    if not item.endswith(".py"):
        os.remove(item)
os.chdir("../Kbtv")
for item in os.listdir("."):
    if not (item.endswith(".py") or item.endswith(".rc")):
        os.remove(item)
os.chdir("../doc")
for item in os.listdir("."):
    for doc in os.listdir(item):
        if doc.endswith(".html") or doc.endswith(".bz2") or doc.endswith("~"):
            os.remove(os.path.join(item, doc))
os.chdir("..")
for item in os.listdir("."):
    if ((item.endswith(".pyc") or item in ("kbtv", "btsetup", "kbtv.desktop")) 
        and not os.path.isdir(item)):
        os.remove(item)
